==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_download_address_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDownloadAddressResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'address': 'list[DownloadAddressForList]'
    }

    attribute_map = {
        'address': 'address'
    }

    def __init__(self, address=None):
        """ListDownloadAddressResponse

        The model defined in huaweicloud sdk

        :param address: 下载地址列表。
        :type address: list[:class:`huaweicloudsdkworkspace.v2.DownloadAddressForList`]
        """
        
        super(ListDownloadAddressResponse, self).__init__()

        self._address = None
        self.discriminator = None

        if address is not None:
            self.address = address

    @property
    def address(self):
        """Gets the address of this ListDownloadAddressResponse.

        下载地址列表。

        :return: The address of this ListDownloadAddressResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.DownloadAddressForList`]
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ListDownloadAddressResponse.

        下载地址列表。

        :param address: The address of this ListDownloadAddressResponse.
        :type address: list[:class:`huaweicloudsdkworkspace.v2.DownloadAddressForList`]
        """
        self._address = address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDownloadAddressResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_download_address_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDownloadAddressResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'address': 'list[DownloadAddressForList]'
    }

    attribute_map = {
        'address': 'address'
    }

    def __init__(self, address=None):
        r"""ListDownloadAddressResponse

        The model defined in huaweicloud sdk

        :param address: 下载地址列表。
        :type address: list[:class:`huaweicloudsdkworkspace.v2.DownloadAddressForList`]
        """
        
        super(ListDownloadAddressResponse, self).__init__()

        self._address = None
        self.discriminator = None

        if address is not None:
            self.address = address

    @property
    def address(self):
        r"""Gets the address of this ListDownloadAddressResponse.

        下载地址列表。

        :return: The address of this ListDownloadAddressResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.DownloadAddressForList`]
        """
        return self._address

    @address.setter
    def address(self, address):
        r"""Sets the address of this ListDownloadAddressResponse.

        下载地址列表。

        :param address: The address of this ListDownloadAddressResponse.
        :type address: list[:class:`huaweicloudsdkworkspace.v2.DownloadAddressForList`]
        """
        self._address = address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDownloadAddressResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
